@@ -113,8 +113,8 @@ def decodeAddPoolLiquidity(hex):
         {'key':'addresses', 'type': [
             {'key': 'from', 'type': 'address','endian':None},
             {'key': 'amounts', 'type': [
-                {'bytesCount': 4,'key': 'tokenId', 'type': int,'endian':'big'},
-                {'bytesCount': 8, 'key': 'amount', 'type': int,'endian':'big'}
+                {'bytesCount': 4,'key': 'tokenId', 'type': int,'endian':'little'},
+                {'bytesCount': 8, 'key': 'amount', 'type': int,'endian':'little'}
                 ]}
         ]},
         {'key': 'shareAddress', 'type': 'address','endian':None}
